function cpmlxvar = readComplexVar(pathname, filename)
% function readComplexVar 
%
%   Reads complex number values from a given filename. In fact, the given 
%   filename is combined with "_r" and "_i" extensions for real and
%   imaginary part files for a complex number. These files contain
%   real-number values for real and imaginary parts of complex numbers. 
%   These files are read by using readVar function.
%
%   cpmlxvar = readComplexVar(pathname, filename)
%
%   INPUTS:
%   pathname: The folder path
%   filename: The filename that will be combined with "_r" and "_i" to read
%   the real part and imaginary part files separately and combine.
%
%   File Structure to be read: Files that will be read by this function are 
%   generally generated by writeComplexVar function. The real ("_r") and 
%   Imaginary ("_i") part files should have the same sized array of values
%   The first line of the file should have the number of dimensinons, 
%   following lines (enugh number of them depending on the number of 
%   dimensions) should have the length of each dimension, then the 
%   following lines should have the values corresponding to the given size.
%   For example:
%   
%   example_r.dat
%   2.0
%   3.0
%   5.0
%   19 25 16 0 44
%   33 18 0  4 43
%   40 28 37 0 47
%   
%   example_i.dat
%   2.0
%   3.0
%   5.0
%   1 2 1 0 4
%   3 1 0 4 13
%   0 2 3 0 40
%
% See also readVar, writeComplexVar.

%   Copyright  2017-2018 Mehmet Kurum, Orhan Eroglu, Dylan R. Boyd

%   This program is free software: You can redistribute it and/or 
%   modify it under the terms of the GNU General Public License as 
%   published by the Free Software Foundation, either version 3 of the 
%   License, or (at your option) any later version.

%   Version: 1.0.0


% Read the real part
filename_real = strcat(filename, '_r') ;
var_real = readVar(pathname, filename_real) ;

% Read the imaginary part
filename_imag = strcat(filename, '_i') ;
var_imag = readVar(pathname, filename_imag) ;

% Combine the complex number values
cpmlxvar = var_real + 1i * var_imag ;


end